@@ -1,18 +1,11 @@
 /* VText.m
  * 2-D Text object
  *
- * Copyright (C) 1996-2012 by vhf interservice GmbH
+ * Copyright (C) 1996-2003 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1996-02-15
- * modified: 2012-02-28 (-drawWithPrincipal: set frame twice to make mirrored text visible)
- *           2012-02-28 (-textDidEndEditing: if locked, we don't adjust the size of the text box)
- *           2010-07-29 (-drawWithPrincipal:...) move -setTextContainerInset: before -setFrame to make mirror on Apple visible
- *           2010-07-28 (+valueForKey:inArray:) new
- *           2009-12-29 (-drawWithPrincipal:): for GNUstep renew drawText after rotAngle
- *           2009-02-12 (-textDidEndEditing: add correction to height to make text appear safely on Apple)
- *           2009-02-11 (-getFlattenedObjectAt: set yOffset for mirrored text)
- *           2009-01-27 (-textDidEndEditing: remove empty text)
+ * modified: 2003-06-26
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -44,8 +37,8 @@
 #include "../FlippedView.h"
 #include "../graphicsUndo.subproj/undo.h"
 
-static NSTextView	*drawText = nil;	// shared Text object used for drawing
-//static NSString	*fontListNoFill;	// list of fonts which shouldn't be filled
+static NSTextView	*drawText = nil;	/* shared Text object used for drawing */
+//static NSString		*fontListNoFill;	/* list of fonts which shouldn't be filled */
 //static BOOL 		displayModeFilled = YES;
 
 //#define FONTLIST_NAME	@"FontListNoFill"
@@ -121,26 +114,6 @@ static void initClassVars()
     return;
 }
 
-/* search given array of Graphics objects
- * and return the substring (value) of a text with a given key
- * ex: "#KEY#Returned String"
- * created: 2010-07-28
- */
-+ (NSString*)valueForKey:(NSString*)key inArray:(NSArray*)array
-{   int         i, cnt = [array count];
-
-    for ( i=0; i<cnt; i++ )
-    {   VText   *g = [array objectAtIndex:i];
-
-        if ( [g isKindOfClass:[VText class]] )
-        {   NSString    *string = [g string];
-
-            if ( [string hasPrefix:key] )
-                return [string substringFromIndex:[key length]];
-        }
-    }
-    return nil;
-}
 
 - (void)renewSharedText
 {
@@ -181,7 +154,6 @@ static void initClassVars()
     endColor = [[NSColor blackColor] retain];
     graduateAngle = 0.0;
     stepWidth = 7.0;
-    radialCenter = NSMakePoint(0.5, 0.5);
     //lineHeight = [[drawText font] pointSize];
     return [super init];
 }
@@ -198,8 +170,7 @@ static void initClassVars()
 
 - (NSString*)description
 {
-    return [NSString stringWithFormat:@"VText: bounds=%f %f %f %f string=%@ angle=%f serial=%d fitHoricontal=%d centerVertical=%d",
-            bounds.origin.x, bounds.origin.y, bounds.size.width, bounds.size.height, [self string], rotAngle, isSerialNumber, fitHorizontal, centerVertical];
+    return [NSString stringWithFormat:@"VText: bounds=%f %f %f %f string=%@ angle=%f serial=%d fitHoricontal=%d centerVertical=%d", bounds.origin.x, bounds.origin.y, bounds.size.width, bounds.size.height, [self string], rotAngle, isSerialNumber, fitHorizontal, centerVertical];
 }
 
 - (NSString*)title
@@ -210,30 +181,11 @@ static void initClassVars()
 - (BOOL)filled			{ return filled; }
 - (void)setFilled:(BOOL)flag	{ filled = flag; dirty = YES; }
 
-/* modified: 2005-06-10
- */
-- (void)setColor:(NSColor *)col
-{
-    [self setFillColor:col];
-}
-
-/* modified: 2005-06-10
- */
 - (void)setFillColor:(NSColor*)col
 {
-    if (attributedString)
-    {   NSTextStorage	*ts = [drawText textStorage];
-
-        [ts beginEditing];
-        [ts setAttributedString:attributedString];
-        [ts endEditing];
-        [drawText setTextColor:col];
-        [drawText setFrame:bounds];
-        [self setAttributedString:[ts attributedSubstringFromRange:NSMakeRange(0, [ts length])]];
-    }
-    [super setColor:col];
     if (fillColor) [fillColor release];
     fillColor = [col retain];
+    [self setColor:fillColor]; // copy else redo kill
     dirty = YES;
 }
 - (NSColor*)fillColor { return fillColor; }
@@ -249,12 +201,24 @@ static void initClassVars()
 - (void)setGraduateAngle:(float)a	{ graduateAngle = a; dirty = YES; }
 - (float)graduateAngle			{ return graduateAngle; }
 
-- (void)setRadialCenter:(NSPoint)rc	{ radialCenter = rc; dirty = YES; }
-- (NSPoint)radialCenter			{ return radialCenter; }
-
 - (void)setStepWidth:(float)sw	{ stepWidth = sw; dirty = YES; }
 - (float)stepWidth		{ return stepWidth; }
 
+- (void)setColor:(NSColor *)col
+{
+    if (attributedString)
+    {   NSTextStorage	*ts = [drawText textStorage];
+
+        [ts beginEditing];
+        [ts setAttributedString:attributedString];
+        [ts endEditing];
+        [drawText setTextColor:col];
+        [drawText setFrame:bounds];
+        [self setAttributedString:[ts attributedSubstringFromRange:NSMakeRange(0, [ts length])]];
+    }
+    [super setColor:col];
+}
+
 - (void)setTextPath:tPath	{ textPath = tPath; }
 
 - (NSString*)string
@@ -280,8 +244,7 @@ static void initClassVars()
     [drawText setHorizontallyResizable:YES];
     [drawText setVerticallyResizable:YES];
     [ts beginEditing];
-    if (attributedString)
-        [ts setAttributedString:attributedString];
+    [ts setAttributedString:attributedString];
     [ts endEditing];
     [drawText setAlignment:NSLeftTextAlignment];
     [drawText setString:s];
@@ -306,7 +269,7 @@ static void initClassVars()
     }
     if (color)
         [drawText setTextColor:color];
-    [drawText sizeToFit];	// collapses to zero for text larger bounds ???
+    [drawText sizeToFit];	/* collapses to zero for text larger bounds ??? */
 
     [self setAttributedString:[ts attributedSubstringFromRange:NSMakeRange(0, [ts length])]];
     [[drawText textContainer] setWidthTracksTextView:YES];
@@ -326,7 +289,7 @@ static void initClassVars()
         font = [aFont retain];
     }
     if (aColor)
-        [self setColor:aColor];	// 2005-06-10
+        [super setColor:aColor];
     [self setString:string lineHeight:lineHeight];
     dirty = YES;
 }
@@ -374,31 +337,6 @@ static void initClassVars()
             [self kernToFitHorizontal];
     }
 }
-- (void)replaceCharactersInRange:(NSRange)range withString:(NSString*)string
-{
-    if (string)
-    {
-        [self makeMutableAttributedString];
-        [attributedString replaceCharactersInRange:range withString:string];
-        if ( [self fitHorizontal] )
-            [self kernToFitHorizontal];
-    }
-}
-/* created: 2005-09-01
- */
-- (void)replaceSubstring:(NSString*)substring withString:(NSString*)string
-{
-    if (string)
-    {   NSRange	range = [[attributedString string] rangeOfString:substring];
-
-        if (range.length)
-        {   [self makeMutableAttributedString];
-            [attributedString replaceCharactersInRange:range withString:string];
-            if ( [self fitHorizontal] )
-                [self kernToFitHorizontal];
-        }
-    }
-}
 
 - (void)makeMutableAttributedString
 {
@@ -460,27 +398,10 @@ static void initClassVars()
     viewBounds = [view bounds];
     dirty = YES;
 
-    /* Here we keep the frame of the editview always 100%, whatever happens */
-    /*{   NSRect  editFrame = [editView frame], newFrame = [view frame];
-
-        editView = [view editView];
-        newFrame.size.width = NSWidth([view frame]) / [view scaleFactor];
-        printf("editView = %.1f bounds = %.1f  newFrame = %.1f  scale = %.1f\n", editFrame.size.width, viewBounds.size.width, newFrame.size.width, [view scaleFactor]);
-        if ( Diff(newFrame.size.width, editFrame.size.width) > 0.1 )
-        {
-            newFrame.size.height = NSHeight([view frame]) / [view scaleFactor];
-            NSLog(@"Note for createText: editView corrected to view size {%.1f %.1f} -> {%.1f %.1f}",
-                  editFrame.size.width, editFrame.size.height, newFrame.size.width, newFrame.size.height);
-            [[view editView] setFrame:newFrame];
-        }
-    }*/
-
     return NSMouseInRect(bounds.origin, viewBounds, NO);
 }
 
 /*
- * modified: 2006-09-20 (scroll text to visible)
- *
  * Here we are going to use the shared field editor for the window to
  * edit the text in the VText.  First, we must end any other editing
  * that is going on with the field editor in this window using endEditingFor:.
@@ -637,11 +558,6 @@ static void initClassVars()
     [fe setDelegate:self];
     [editView addSubview:fe];
 
-/* doesn't work ! #ifdef __APPLE__    // Workaround: display Single Line Fonts
-    if ( VHFAntialiasing() && [[font fontName] hasSuffix:@"-1Line"] )
-        VHFSetAntialiasing(NO);
-#endif*/
-
     //[fe display];	/* redraw because although we may have black background we edit on a white background*/
 
     /* Make it the first responder.
@@ -659,7 +575,6 @@ static void initClassVars()
 	[fe setSelectedRange:(NSRange){0,0}];
 
     [fe toggleRuler:self];
-    [view scrollRectToVisible:frame];	// if ruler covers text -> scroll text to visible
 
     return YES;
 }
@@ -675,18 +590,21 @@ static void initClassVars()
 }
 
 - (void)editorFrameChanged:(NSNotification *)arg
-{   NSRect  currentEditingFrame = [[arg object] frame];
+{
+    NSRect currentEditingFrame = [[arg object] frame];
 
     if (!NSEqualRects(lastEditingFrame, NSZeroRect))
     {
         if (lastEditingFrame.size.width > currentEditingFrame.size.width)
-        {   NSRect  updateRect = lastEditingFrame;
+        {
+            NSRect updateRect = lastEditingFrame;
 
             updateRect.origin.x = currentEditingFrame.origin.x + currentEditingFrame.size.width;
             [self updateEditingViewRect:updateRect];
         }
         if (lastEditingFrame.size.height > currentEditingFrame.size.height)
-        {   NSRect updateRect = lastEditingFrame;
+        {
+            NSRect updateRect = lastEditingFrame;
 
             updateRect.origin.y = currentEditingFrame.origin.y + currentEditingFrame.size.height;
             [self updateEditingViewRect:updateRect];
@@ -1006,21 +924,9 @@ static void initClassVars()
  * draws the text
  */
 - (void)drawWithPrincipal:principal
-{   id              window = [principal window];
-    BOOL            saveAutoDisplay = [window isAutodisplay];
-    NSLayoutManager *lm = [drawText layoutManager];
-
-#ifdef __APPLE__    // Workaround: display Single Line Fonts
-    BOOL    antialias = VHFAntialiasing();
-    if ( antialias && [[font fontName] hasSuffix:@"-1Line"] )
-        VHFSetAntialiasing(NO);
-    /*if ( NSAppKitVersionNumber < NSAppKitVersionNumber10_6  // < 10.6
-         && [[font fontName] hasSuffix:@"-1Line"] )         // Single Line Font
-    {   VPath   *path = [self getFlattenedObjectAt:NSMakePoint(0.0, 0.0) withOffset:0];
-        [path drawWithPrincipal:principal];
-        return;
-    }*/
-#endif
+{   id			window = [principal window];
+    BOOL		saveAutoDisplay = [window isAutodisplay];
+    NSLayoutManager	*lm = [drawText layoutManager];
 
     editView = [principal editView];	// needed in flatten object
 
@@ -1065,8 +971,8 @@ static void initClassVars()
             int		i, cnt = [mas length];
 
             for (i=0; i<cnt; i++)
-            {   NSRange range;
-                NSColor *colorAtt;
+            {   NSRange			range;
+                NSColor			*colorAtt;
 
                 colorAtt = [mas attribute:@"NSColor" atIndex:i longestEffectiveRange:&range
                                   inRange:NSMakeRange(0, cnt)];
@@ -1085,12 +991,11 @@ static void initClassVars()
             [[drawText textStorage] setAttributedString:attributedString];
 
         [[drawText textStorage] endEditing];
-        [drawText setTextContainerInset:NSMakeSize(0.0, 0.0)];  // 2010-07-29: moved before setFrame: for Apple mirror
         [drawText setFrame:bounds];
-        [drawText setFrame:bounds]; // 2012-02-28: well, without this extra invitation Apple doesn't draw mirrored text !
-        //[drawText writeRTFDToFile:@"/tmp/text.rtf" atomically:NO];	// debugging
+        //[drawText writeRTFDToFile:@"/tmp/text.rtf" atomically:NO];	// test
         //[drawText setFrame:bounds];
 
+        [drawText setTextContainerInset:NSMakeSize(0.0, 0.0)];
         if ( centerVertical )	// vertical center: (bounds.size.height-textHeight)/2
         {   NSRect	rect = [lm boundingRectForGlyphRange:NSMakeRange(0, [lm numberOfGlyphs])
                                              inTextContainer:[drawText textContainer]];
@@ -1108,23 +1013,11 @@ static void initClassVars()
         [drawText removeFromSuperview];
         [window setAutodisplay:saveAutoDisplay];
         [drawText scaleUnitSquareToSize:NSMakeSize(1.0, 1.0/aspectRatio)];
-#ifdef GNUSTEP_BASE_VERSION // 2009-12-29 gui 0.17.1: GNUstep workaround, rotation screws up everything
-        if ( rotAngle != 0.0 )
-        {   [drawText release]; drawText = nil;
-            initClassVars();
-        }
-#endif
-        //[drawText setFrameRotation:0.0];
     	/*if (DrawStatus == Resizing)
     	{   [[NSColor lightGrayColor] set];
             NSFrameRect(bounds);
     	}*/
     }
-
-#ifdef __APPLE__    // Workaround: display Single Line Fonts
-    if (antialias)
-        VHFSetAntialiasing(antialias);
-#endif
 }
 
 /* extract number from data, increment this number and add it to data. Then write string to drawText
@@ -1284,7 +1177,7 @@ static void initClassVars()
 }
 
 - (NSRect)textBox		{ return bounds; }
-- (void)setTextBox:(NSRect)rect	{ bounds = rect; [self kernToFitHorizontal]; dirty = YES; } // 2008-02-05
+- (void)setTextBox:(NSRect)rect	{ bounds = rect; dirty = YES; }
 
 /*
  * Depending on the pt_num passed in, return the rectangle
@@ -1548,17 +1441,15 @@ static void initClassVars()
  * We must remove the Text object from the view heirarchy and, since
  * this Text object is going to be reused, we must set its delegate
  * back to nil.
- * For further explanation of the two "ack!" lines, see edit:in: above.
  *
- * modified: 2012-02-28 (if isLocked, we don't adjust the size of the text box)
- *           2009-02-12
+ * For further explanation of the two "ack!" lines, see edit:in: above.
  */
 - (void)textDidEndEditing:(NSNotification *)notification
-{   NSTextView          *fe = [notification object];
-    NSRect              oldBounds;
-    NSPoint             o;
-    float               correction = 2.0;	// ? we use this to increase the bounds that contain the text
-    NSAttributedString  *as;
+{   NSTextView		*fe = [notification object];
+    NSRect		oldBounds;
+    NSPoint		o;
+    float		correction = 2.0;	/* ? we use this to increase the bounds to contain the text */
+    NSAttributedString	*as;
 
     if ( fe )
     {
@@ -1568,11 +1459,11 @@ static void initClassVars()
         if ([fe isRulerVisible])
             [fe toggleRuler:self];
 
-        if ( [[fe string] length] || attributedString )
-        {   id	change = nil;
+        if ( ![[fe string] length] )
+            [fe setString:@"*"];
 
-            if ( ![[fe string] length] )
-                [fe setString:@"EMPTY TEXT"];
+        if ( [[fe string] length] )
+        {   id	change = nil;
 
             if ( attributedString )
             {   change = [[EndEditingGraphicsChange alloc] initGraphicView:graphicView graphic:self];
@@ -1587,14 +1478,11 @@ static void initClassVars()
 
             oldBounds = [self extendedBoundsWithScale:[graphicView scaleFactor]];
             [fe setVerticallyResizable:YES];
-            if ( ! isLocked )
-            {   [fe sizeToFit];
-                bounds = [fe frame];
-                bounds.size = [fe bounds].size;
-                bounds.size.width  += correction;
-                bounds.size.height += correction;   // origin = upper/left here!
-                bounds = [editView convertRect:bounds toView:graphicView];  // ack!
-            }
+            [fe sizeToFit];
+            bounds = [fe frame];
+            bounds.size = [fe bounds].size;
+            bounds.size.width += correction;
+            bounds = [editView convertRect:bounds toView:graphicView];  // ack!
             //bounds = [graphicView centerScanRect:bounds];	/* center pixels */
             //redrawRect = NSUnionRect(bounds, redrawRect);
 
@@ -1607,9 +1495,8 @@ static void initClassVars()
             //[[graphicView window] disableFlushWindow];
             o = bounds.origin;
             o.y += bounds.size.height;
-            vhfRotatePointAroundCenter(&bounds.origin, o, rotAngle); // new origin
+            vhfRotatePointAroundCenter(&bounds.origin, o, rotAngle); /* new origin */
             oldBounds = NSUnionRect(bounds, oldBounds);
-            [[graphicView layerOfGraphic:self] updateObject:self];  // 2008-02-05
             [(DocView*)graphicView cache:oldBounds];
             //[graphicView draw:oldBounds];	/* update cache */
             //[(NSView*)graphicView lockFocus];
@@ -1675,16 +1562,7 @@ static void initClassVars()
 
 #ifdef __APPLE__
     {   NSBezierPath	*bezierPath = [NSBezierPath bezierPath];
-        NSFont          *fnt;
-        float           yOffset = 0.0;
-
-        /* workaround for offset in older OS X versions, not knowing exactly when it was fixed
-         * It seems vertical centered text needs this offset.
-         */
-        if ( centerVertical /*|| NSAppKitVersionNumber < 824.42*/ )   // Mac OS X < 10.4.10
-            yOffset = Max(0.0, (bounds.size.height-rect.size.height-1.0)/2.0);
-        if ( aspectRatio < 0.0 )    // mirrored text
-            yOffset -= bounds.size.height; // Apple needs that
+        NSFont		*fnt;
 
         cnt = [lm numberOfGlyphs];
         if (cnt > 1)
@@ -1697,20 +1575,18 @@ static void initClassVars()
             p = [lm locationForGlyphAtIndex:i];
             [bezierPath removeAllPoints];
             [bezierPath moveToPoint:NSMakePoint(bRect.origin.x+rect.origin.x+p.x,
-                                                bRect.origin.y+bRect.size.height-rect.origin.y-p.y-yOffset)];
+                                                bRect.origin.y+bRect.size.height-rect.origin.y-p.y)];
             fnt = [[drawText textStorage] attribute:NSFontAttributeName atIndex:i effectiveRange:NULL];
             [bezierPath appendBezierPathWithGlyph:[lm glyphAtIndex:i] inFont:fnt];
             pathG = [VPath pathWithBezierPath:bezierPath];
             [pathG setWidth:0.0];
-            //printf("y=%.0f h=%.0f lh=%.0f  oberkannte=%.0f  vorstellung=%.0f\n", bRect.origin.y, bRect.size.height, [self lineHeight], bRect.origin.y+bRect.size.height, bRect.origin.y+bRect.size.height-([self lineHeight]*aspectRatio/2.0));
-             /* /2.0 war bis 2007-10-26, tut nicht mit 10.4.10 (824.42) */
             if (aspectRatio != 1.0)
                 [pathG scale:1.0 :aspectRatio
-                  withCenter:NSMakePoint(1.0, bRect.origin.y+bRect.size.height/1.0)];
+                  withCenter:NSMakePoint(1.0, bRect.origin.x+bRect.size.height/2.0)];
             [pathG setAngle:-rotAngle withCenter:bRect.origin];
             /* FIXME: stroked fonts shouldn't be filled! */
             [pathG setFilled:YES optimize:NO];
-            if ( group && [pathG count] )
+            if (group)
                 [group addObject:pathG];
         }
 
@@ -1779,7 +1655,7 @@ static void initClassVars()
                 [pathG setFillColor:[[[list objectAtIndex:i]fillColor]
                                      colorUsingColorSpaceName:NSDeviceCMYKColorSpace]];
             if (cnt>1)
-                [group addObject:pathG];	 //[[group list] addObject:pathG];
+                [[group list] addObject:pathG];
         }
         if ( !pathG )
             pathG = [VPath path];
@@ -1806,7 +1682,6 @@ static void initClassVars()
     [aCoder encodeObject:fillColor];
     [aCoder encodeObject:endColor];
     [aCoder encodeValuesOfObjCTypes:"ff", &graduateAngle, &stepWidth];
-    [aCoder encodeValuesOfObjCTypes:"{NSPoint=ff}", &radialCenter];
 }
 - (id)initWithCoder:(NSCoder *)aDecoder
 {   int	version;
@@ -1841,7 +1716,6 @@ static void initClassVars()
     {   fillColor = [[aDecoder decodeObject] retain];
         endColor = [[aDecoder decodeObject] retain];
         [aDecoder decodeValuesOfObjCTypes:"ff", &graduateAngle , &stepWidth];
-        [aDecoder decodeValuesOfObjCTypes:"{NSPoint=ff}", &radialCenter];
     }
     if ( version < 1 )
     {   float	f;
@@ -1866,17 +1740,10 @@ static void initClassVars()
     if (isSerialNumber) [plist setObject:@"YES" forKey:@"isSerialNumber"];
     if (fitHorizontal) [plist setObject:@"YES" forKey:@"fitHorizontal"];
     if (centerVertical) [plist setObject:@"YES" forKey:@"centerVertical"];
-
-    if (fillColor != [NSColor blackColor])
-        [plist setObject:propertyListFromNSColor(fillColor) forKey:@"fillColor"];
-    if (endColor != [NSColor blackColor])
-        [plist setObject:propertyListFromNSColor(endColor) forKey:@"endColor"];
-    if (graduateAngle)
-        [plist setObject:propertyListFromFloat(graduateAngle) forKey:@"graduateAngle"];
-    if (stepWidth != 7)
-        [plist setObject:propertyListFromFloat(stepWidth) forKey:@"stepWidth"];
-    if (radialCenter.x != 0.5 && radialCenter.y != 0.5)
-        [plist setObject:propertyListFromNSPoint(radialCenter) forKey:@"radialCenter"];
+    [plist setObject:propertyListFromNSColor(fillColor) forKey:@"fillColor"];
+    [plist setObject:propertyListFromNSColor(endColor) forKey:@"endColor"];
+    [plist setObject:propertyListFromFloat(graduateAngle) forKey:@"graduateAngle"];
+    [plist setObject:propertyListFromFloat(stepWidth) forKey:@"stepWidth"];
 
     return plist;
 }
@@ -1886,25 +1753,18 @@ static void initClassVars()
     [super initFromPropertyList:plist inDirectory:directory];
     rotAngle = [plist floatForKey:@"rotAngle"];
     aspectRatio = [plist floatForKey:@"aspectRatio"];
-    [self setRichTextData:[plist objectForKey:@"data"]];    // this also loads the text colors for paragraphs !
+    [self setRichTextData:[plist objectForKey:@"data"]];
     bounds = rectFromPropertyList([plist objectForKey:@"bounds"]);
     isSerialNumber = ([plist objectForKey:@"isSerialNumber"] ? YES : NO);
     fitHorizontal = ([plist objectForKey:@"fitHorizontal"] ? YES : NO);
     centerVertical = ([plist objectForKey:@"centerVertical"] ? YES : NO);
     [self font];
-
-    fillColor = colorFromPropertyList([plist objectForKey:@"fillColor"], [self zone]);
-    /*if (!(fillColor = colorFromPropertyList([plist objectForKey:@"fillColor"], [self zone])))
-        [self setFillColor:[color copy]];   // destroys paragraph colors !*/
+    if (!(fillColor = colorFromPropertyList([plist objectForKey:@"fillColor"], [self zone])))
+        [self setFillColor:[color copy]];
     if (!(endColor = colorFromPropertyList([plist objectForKey:@"endColor"], [self zone])))
         [self setEndColor:[NSColor blackColor]];
     graduateAngle = [plist floatForKey:@"graduateAngle"];
-    if ( !(stepWidth = [plist floatForKey:@"stepWidth"]))
-        stepWidth = 7.0;	// default;
-    if ([plist objectForKey:@"radialCenter"])
-        radialCenter = pointFromPropertyList([plist objectForKey:@"radialCenter"]);
-    else
-        radialCenter = NSMakePoint(0.5, 0.5);	// default
+    stepWidth = [plist floatForKey:@"stepWidth"];
     return self;
 }
 
