@@ -1,13 +1,12 @@
 /* GerberImport.m
  * Gerber import object (RS274X)
  *
- * Copyright (C) 1996-2005 by vhf interservice GmbH
+ * Copyright (C) 1996-2003 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *           Ilonka Fleischmann
  *
  * created:  1996-05-03
- * modified: 2009-07-10 (// state.g = 0; -getLayerPolarity: ![scanner isAtEnd])
- *           2006-03-24
+ * modified: 2002-10-26
  *
  * This file is part of the vhf Import Library.
  *
@@ -476,19 +475,19 @@ static void addToBeginNew(NSString *newOp, NSMutableString *beginNew)
     [scanner scanInt:&d];
     [scanner setScanLocation:location];
     if ( ([scanner scanString:ops.draw intoString:NULL] ||
-         [scanner scanString:ops.draw01 intoString:NULL]) && d==1 ) // D01
+         [scanner scanString:ops.draw01 intoString:NULL]) && d==1 )
     {
         state.lightCode = 1;
         return YES;
     }
     else if ( ([scanner scanString:ops.move intoString:NULL] ||
-              [scanner scanString:ops.move02 intoString:NULL]) && d==2) // D02
+              [scanner scanString:ops.move02 intoString:NULL]) && d==2)
     {
         state.lightCode = 2;
         return YES;
     }
     else if ( ([scanner scanString:ops.flash intoString:NULL] ||
-              [scanner scanString:ops.flash03 intoString:NULL]) && d==3 ) // D03
+              [scanner scanString:ops.flash03 intoString:NULL]) && d==3 )
     {
         state.lightCode = 3;
         state.draw = 1; /* x123y123D02* D03* */
@@ -509,14 +508,14 @@ static void addToBeginNew(NSString *newOp, NSMutableString *beginNew)
     {   [scanner scanUpToString:ops.termi intoString:NULL];
         [scanner scanString:ops.termi intoString:NULL];
     }
-    else if ( [scanner scanString:ops.polyBegin intoString:NULL] ) // G36	
+    else if ( [scanner scanString:ops.polyBegin intoString:NULL] )	
     {
         state.lightCode = 2; // off
         state.draw = 1;
         state.path = 1;
         state.g = Gerber_PATH;
     }
-    else if ( [scanner scanString:ops.polyEnd intoString:NULL] ) // G37
+    else if ( [scanner scanString:ops.polyEnd intoString:NULL] )	
     {
         state.lightCode = 2; // off
         state.path = 0;
@@ -606,19 +605,15 @@ static void addToBeginNew(NSString *newOp, NSMutableString *beginNew)
                         default:
                             [self setLine:cList];
                     }
-//                    state.g = 0;
+                    state.g = 0;
                     break;
                 case 3: /* flash */
                     [self setPad:list];
                     state.g = 0;
                     break;
                 default: /* off */
-                    if (state.path && [cList count])
-                        [self setLine:cList];
-                    else
-                    {   state.point.x = state.x;
-                        state.point.y = state.y;
-                    }
+                    state.point.x = state.x;
+                    state.point.y = state.y;
                     if ( state.path && state.g == Gerber_PATH )
                         [self setPath:scanner :cList];
                 state.g = 0;
@@ -893,7 +888,7 @@ void replaceFromByTo(NSString** macroStr, NSString* from, NSString* to, int cnt,
         else // the values follows directly behind , (comma) -> we must combine them with $1 values in macroData
         {   NSScanner	*mScanner = [NSScanner scannerWithString:macroData];
             NSString	*searchStr = [NSString stringWithFormat:@"%%AM%@", macroName];
-            NSRange	range, rangeHack;
+            NSRange	range;
             int		i, cnt = 0;
             float	vals[200]; // I hope no one will write an greater macro
 
@@ -915,48 +910,10 @@ void replaceFromByTo(NSString** macroStr, NSString* from, NSString* to, int cnt,
             }
             // replace $1, $2 $n with values from scanner
             range = [*macroStr rangeOfString:@"="];
-            /* Eagle WorkAround */
-            rangeHack = [*macroStr rangeOfString:@"X$"];
             for (i=0; i<cnt; i++)
             {   NSString	*from = [NSString stringWithFormat:@"$%d", i+1];
                 NSString	*to = [NSString stringWithFormat:@"%.3f", vals[i]];
 
-                /* Eagle WorkAround */
-                if ( rangeHack.length )
-                {   NSScanner	*mcrScanner = [NSScanner scannerWithString:*macroStr];
-                    NSString	*string;
-
-                    NSLog(@"Eagle WorkAround wurde aktiviert\n");
-                    /*  * 5,1,8,0,0,1.08239X$1,22.5  - werte zwischen den Kommas */
-                    /* we must remove the float before/and the X */
-                    /* and we must set the last float to 0 - rotation of polygon */
-
-                    while ( ![mcrScanner isAtEnd] )
-                    {
-                        [mcrScanner scanUpToString:@"," intoString:&string];
-                        rangeHack = [string rangeOfString:@"X$"];
-                        /* this is our string part - wert zwischen den kommas */
-                        if ( rangeHack.length )
-                        {   NSScanner		*mmScanner = [NSScanner scannerWithString:string];
-                            NSMutableString	*fromHack = [NSMutableString stringWithString:string], *toHack;
-                            NSString		*restString;
-
-                            [mcrScanner scanUpToString:@"*" intoString:&restString]; // ,22.5 rotation
-                            [fromHack appendString:restString];
-
-                            [mmScanner scanUpToString:@"$" intoString:NULL]; // bis $
-                            [mmScanner scanUpToString:@"," intoString:&toHack]; // bis , -> $1 oder $3
-
-                            /* and we must set the last float to 0 - rotation of polygon */
-                            toHack = [NSMutableString stringWithString:toHack];
-                            [toHack appendString:@",0"]; // no rotation
-                            *macroStr = [*macroStr stringByReplacing:fromHack by:toHack];
-                            break;
-                        }
-                        [mcrScanner scanString:@"," intoString:NULL];
-                    }
-                }
-
                 if ( !range.length )
                     *macroStr = [*macroStr stringByReplacing:from by:to];
                 else
@@ -1004,7 +961,7 @@ void replaceFromByTo(NSString** macroStr, NSString* from, NSString* to, int cnt,
 - (BOOL)getLayerPolarity:(NSScanner*)scanner
 {
     // until %
-    while ( ![scanner scanString:ops.RS274X intoString:NULL] && ![scanner isAtEnd] )
+    while ( ![scanner scanString:ops.RS274X intoString:NULL] )
     {
         if ( [scanner scanString:@"LP" intoString:NULL] ) // no layer polarity
         {
@@ -1598,7 +1555,7 @@ void replaceFromByTo(NSString** macroStr, NSString* from, NSString* to, int cnt,
         [self addFillPath:dList toList:mList];
         dList=[[[self allocateList] init] autorelease];
 
-        // set 4 points of horicontal line
+        // set 4 points of horicontal (   ) line
         p[0].x = cx - lenCross/2.0; p[0].y = cy - wCross/2.0;
         p[1].x = p[0].x + lenCross; p[1].y = p[0].y;
         p[2].x = p[1].x; p[2].y = p[1].y + wCross;
@@ -1695,7 +1652,7 @@ void replaceFromByTo(NSString** macroStr, NSString* from, NSString* to, int cnt,
 
         [self addFillPath:dList toList:mList];
 
-        // set 4 points of horicontal ( –  ) line
+        // set 4 points of horicontal (   ) line
         p[0].x = cx - (dOut2 + 1.0); p[0].y = cy - (wCross/2.0 + 1.0);
         p[1].x = p[0].x + dOut + 2.0; p[1].y = p[0].y;
         p[2].x = p[1].x; p[2].y = p[1].y + wCross + 2.0;
@@ -1777,8 +1734,7 @@ void replaceFromByTo(NSString** macroStr, NSString* from, NSString* to, int cnt,
         p1.y = state.point.y + y;
     }
 
-    if (SqrDistPoints(p0, p1) > TOLERANCE*TOLERANCE)
-        [self addLine:p0 :p1 toList:cList];
+    [self addLine:p0 :p1 toList:cList];
 
     state.point = p1;
 
@@ -1955,7 +1911,7 @@ void replaceFromByTo(NSString** macroStr, NSString* from, NSString* to, int cnt,
 
 /*
  * created:   07.05.93
- * modified:  17.06.93 05.05.96 2009-07-10 (//state.g = 0)
+ * modified:  17.06.93 05.05.96
  * purpose:   set arc ccw
  * parameter: g
  */
@@ -1964,7 +1920,7 @@ void replaceFromByTo(NSString** macroStr, NSString* from, NSString* to, int cnt,
     float		ba, ea, angle;
     NSDictionary	*tool = [tools objectAtIndex:state.tool];
 
-//    state.g = 0; // else we go on with an arc
+    state.g = 0; // else we go on with an arc
 
     if ( !state.path )
         state.width = [[tool objectForKey:@"width"] floatValue];
@@ -1988,9 +1944,6 @@ void replaceFromByTo(NSString** macroStr, NSString* from, NSString* to, int cnt,
     else
         angle = ea - ba;
 
-    if ( Diff(Abs(angle), 0.0) <= TOLERANCE || Diff(Abs(angle), 360.0) <= TOLERANCE )
-        angle = (angle > 0) ? 360.0 : -360.0;
-
     if ( state.ipolFull && Diff(angle, 360.0) <= TOLERANCE )
     {
         if ( state.path )
